isReady property
bool
get
isReady
The one check a host app needs before showing a product's entry point.
Implementation
bool get isReady => status == AppwinInitStatus.ready;
The one check a host app needs before showing a product's entry point.
bool get isReady => status == AppwinInitStatus.ready;