AppwinUnavailableReason enum

Why a product is closed to this app.

Inheritance
Available extensions

Values

plan → const AppwinUnavailableReason

The organisation's plan does not include this product. The studio cannot fix this from the dashboard: it is a sales conversation.

disabled → const AppwinUnavailableReason

The product is switched off for this project. The studio turns it back on from the dashboard, without shipping an app update.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppwinUnavailableReason>
A constant List of the values in this enum, in order of their declaration.