AppwinCoreMethodChannel class
Method-channel implementation of AppwinCorePlatform.
- Inheritance
-
- Object
- PlatformInterface
- AppwinCorePlatform
- AppwinCoreMethodChannel
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bootstrapSession(
{String? externalId}) → Future< String> -
override
-
clearIdentity(
) → Future< void> -
override
-
configure(
{required String appId, String? baseUrl, String? realtimeBaseUrl}) → Future< void> -
override
-
deviceId(
) → Future< String?> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
hasRegisteredPushToken(
) → Future< bool> -
override
-
identify(
{required String externalId}) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerPushToken(
{required String token, String? platform, bool pushOptIn = true}) → Future< void> -
override
-
signOut(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited